/* This is -*- C -*- */
/* $Id: guppi-seq-string-impl.h,v 1.8 2001/01/16 23:36:22 trow Exp $ */

/*
 * guppi-seq-string-impl.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org> and
 * Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_SEQ_STRING_IMPL_H
#define _INC_GUPPI_SEQ_STRING_IMPL_H

/* #include <gtk/gtk.h> */

#include "guppi-seq-string.h"
#include "guppi-seq-impl.h"

#include <guppi-defs.h>

BEGIN_GUPPI_DECLS 

typedef struct _GuppiSeqStringImpl GuppiSeqStringImpl;

struct _GuppiSeqStringImpl {
  GuppiSeqImpl parent;
};

typedef struct {
  GuppiSeqImplClass parent_class;

  /* Virtual functions */
  const gchar *(*get) (const GuppiSeqStringImpl *, gint);
  void (*set) (GuppiSeqStringImpl *, gint, gchar *);
  void (*insert) (GuppiSeqStringImpl *, gint, gchar *);
    gint (*lookup) (GuppiSeqStringImpl *, const gchar *);
    gboolean (*contains) (GuppiSeqStringImpl *, const gchar *);
    gsize (*distinct) (GuppiSeqStringImpl *);

} GuppiSeqStringImplClass;

#define GUPPI_TYPE_SEQ_STRING_IMPL (guppi_seq_string_impl_get_type())
#define GUPPI_SEQ_STRING_IMPL(obj) (GTK_CHECK_CAST((obj),GUPPI_TYPE_SEQ_STRING_IMPL,GuppiSeqStringImpl))
#define GUPPI_SEQ_STRING_IMPL0(obj) ((obj) ? (GUPPI_SEQ_STRING_IMPL(obj)) : NULL)
#define GUPPI_SEQ_STRING_IMPL_CLASS(klass) (GTK_CHECK_CLASS_CAST((klass),GUPPI_TYPE_SEQ_STRING_IMPL,GuppiSeqStringImplClass))
#define GUPPI_IS_SEQ_STRING_IMPL(obj) (GTK_CHECK_TYPE((obj), GUPPI_TYPE_SEQ_STRING_IMPL))
#define GUPPI_IS_SEQ_STRING_IMPL0(obj) (((obj) == NULL) || (GUPPI_IS_SEQ_STRING_IMPL(obj)))
#define GUPPI_IS_SEQ_STRING_IMPL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_SEQ_STRING_IMPL))

GtkType guppi_seq_string_impl_get_type (void);

GtkObject *guppi_seq_string_impl_new (void);



END_GUPPI_DECLS

#endif /* _INC_GUPPI_SEQ_STRING_IMPL_H */

/* $Id: guppi-seq-string-impl.h,v 1.8 2001/01/16 23:36:22 trow Exp $ */
